@@ -6,6 +6,8 @@ use std::{
     ptr::{self, addr_of_mut},
     slice,
 };
+#[cfg(feature = "deps")]
+pub mod deps {}
 
 /// Represents a TCP server.
 pub type NSTDTCPServer = *mut TcpListener;
@@ -290,7 +292,7 @@ pub unsafe extern "C" fn nstd_std_net_udp_socket_close(socket: *mut NSTDUDPSocke
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
 pub unsafe extern "C" fn nstd_std_net_free_ip(ip: *mut *mut c_char) {
-    CString::from_raw(*ip);
+    drop(CString::from_raw(*ip));
     *ip = ptr::null_mut();
 }
 
